==> rktSQLite_2.0.zip: rktSQLite2/webapp/modules/browse/browse.php <==
<?php
/* ========================================================================
 - [browse/browse.php]
 - 内容：テーブルの閲覧
 - 作成：高橋 裕志郎
 - ライセンス:
 -      This source file is subject to version 3.0 of the PHP license,
 -      that is available at http://www.php.net/license/3_0.txt
 -      If you did not receive a copy of the PHP license and are unable 
 -      to obtain it through the world-wide-web, please send a note to 
 -      license@php.net so we can mail you a copy immediately.  
 - 問い合わせ先：
 -      yujiro@rakuto.net
 -      http://www.rakuto.net/study/htdocs/
 -      Copyright (C) 2005 `rakuto.net'. All Rights Reserved.
 - 更新履歴：
 -      [2005/01/08] 作成
 - ======================================================================== */

/* =-=- モジュール等の読み込み -=-= */
require_once WEBAPP_LIB_DIR.'rsl_webapp.php';

/**
 * WebApplication実装クラス
 *
 * @author 高橋 裕志郎 <yujiro@rakuto.net>
 * @package webapp
 * @access public
 * @version 1.0
 */
class webapp extends RSL_webapp
{
    /**
     * 実行処理
     *
     * @access public
     * @return void
     **/
    public function execute()
    {
        $this->template_file = 'browse/browse.tpl';
        $this->addCss('common.css');

        $this->set_list();
    }

    /**
     * テーブルリストの設定
     *
     * @access private
     * @return void
     **/
    private function set_list()
    {
        /* データの取得 */
        $stmt = $this->objdb->prepare("SELECT name FROM sqlite_master WHERE type='table' ORDER BY name"); 
        $stmt->execute(); 

        $list = array();
        $cols = array();
        while ($cols = $stmt->fetch(PDO_FETCH_ASSOC)) { 
            $count = $this->get_count($cols['name']);
            $list[] = array(
                    'name'=> $cols['name'],
                    'count'=>$count
                );
        } 

        $this->Assign('list', $list);
    }

    /**
     * レコード数の取得
     *
     * @access private
     * @param string $name
     * @return integer
     **/
    private function get_count($name)
    {
        /* データの取得 */
        $stmt = $this->objdb->prepare("SELECT count(*) FROM ".$name); 
        $stmt->execute(); 
        $count = $stmt->fetchSingle();
        $count = empty($count)?0:$count;
        
        return $count;
    }
} // webapp
?>

==> rktSQLite2.1.06.zip: rktSQLite2/webapp/modules/browse/browse.php <==
<?php
/* ========================================================================
 - [browse/browse.php]
 - 内容：テーブルの閲覧
 - 作成：高橋 裕志郎
 - ライセンス:
 -      This source file is subject to version 3.0 of the PHP license,
 -      that is available at http://www.php.net/license/3_0.txt
 -      If you did not receive a copy of the PHP license and are unable 
 -      to obtain it through the world-wide-web, please send a note to 
 -      license@php.net so we can mail you a copy immediately.  
 - 問い合わせ先：
 -      yujiro@rakuto.net
 -      http://www.rakuto.net/study/htdocs/
 -      Copyright (C) 2005 `rakuto.net'. All Rights Reserved.
 - 更新履歴：
 -      [2006/03/05] PDO1.0以降に対応
 -      [2005/01/08] 作成
 - ======================================================================== */

/* =-=- モジュール等の読み込み -=-= */
require_once WEBAPP_LIB_DIR.'rsl_webapp.php';

/**
 * WebApplication実装クラス
 *
 * @author 高橋 裕志郎 <yujiro@rakuto.net>
 * @package webapp
 * @access public
 * @version 1.0
 */
class webapp extends RSL_webapp
{
    /**
     * 実行処理
     *
     * @access public
     * @return void
     **/
    public function execute()
    {
        $this->template_file = 'browse/browse.tpl';
        $this->addCss('common.css');

        $this->set_list();
    }

    /**
     * テーブルリストの設定
     *
     * @access private
     * @return void
     **/
    private function set_list()
    {
        /* データの取得 */
        $stmt = $this->objdb->prepare("SELECT name FROM sqlite_master WHERE type='table' ORDER BY name"); 
        $stmt->execute(); 

        $list = array();
        $cols = array();
        while ($cols = $stmt->fetch(PDO::FETCH_ASSOC)) { 
            $count = $this->get_count($cols['name']);
            $list[] = array(
                    'name'=> $cols['name'],
                    'count'=>$count
                );
        } 

        $this->Assign('list', $list);
    }

    /**
     * レコード数の取得
     *
     * @access private
     * @param string $name
     * @return integer
     **/
    private function get_count($name)
    {
        /* データの取得 */
        $stmt = $this->objdb->prepare("SELECT count(*) as ct FROM ".$name); 
        $stmt->execute(); 
        $reslut = $stmt->fetch(PDO::FETCH_ASSOC);
        $count = empty($reslut['ct'])?0:$reslut['ct'];
        
        return $count;
    }
} // webapp
?>
